# AirobotLibrary

全端自动化测试框架Airobots的扩展插件库，集成以下扩展库

    selenium
    appium
    robotframework
    robotframework-seleniumlibrary
    robotframework-appiumlibrary
    robotframework-requests 
    robotframework-databaselibrary
    robotframework-ftplibrary 
    robotframework-archivelibrary 
    robotframework-difflibrary 

请自行在 `https://npm.taobao.org/mirrors/chromedriver` 下载跟Chrome浏览器版本对应的驱动，放在系统PATH中。
